Rally Specs
===========

Specs are detailed description of proposed changes in project. Usually they
answer on what, why, how to change in project and who is going to work on
change.

This directory contains 2 subdirectories:

- in-progress - These specs are approved, but they are not implemented yet
- implemented - Implemented specs archive

If you are looking for full rally road map overview go `here <https://docs.google.com/a/mirantis.com/spreadsheets/d/16DXpfbqvlzMFaqaXAcJsBzzpowb_XpymaK2aFY2gA2g/edit#gid=0>`_.

